@@ -3,9 +3,9 @@
 
 #include <string.h>
 #include <errno.h>
-#include <S.h>
 #include <R.h>
 #include <Rdefines.h>
+#include "R_ext/Error.h"
 
 #ifdef _SPLUS_
 #  define STRING_ELT(x,i) (CHARACTER_POINTER(x)[i])
